[libclc] 9fec0a0 - [libclc] Disable external-calls testing for clspv targets (#127529)

via cfe-commits cfe-commits at lists.llvm.org
Tue Feb 18 01:14:09 PST 2025


Author: Fraser Cormack
Date: 2025-02-18T09:14:04Z
New Revision: 9fec0a0942f5a11f4dcfec20aa485a8513661720

URL: https://github.com/llvm/llvm-project/commit/9fec0a0942f5a11f4dcfec20aa485a8513661720
DIFF: https://github.com/llvm/llvm-project/commit/9fec0a0942f5a11f4dcfec20aa485a8513661720.diff

LOG: [libclc] Disable external-calls testing for clspv targets (#127529)

These targets don't include all OpenCL builtins, so there will always be
external calls in the final bytecode module.

Fixes #127316.

Added: 
    

Modified: 
    libclc/cmake/modules/AddLibclc.cmake

Removed: 
    


################################################################################
diff  --git a/libclc/cmake/modules/AddLibclc.cmake b/libclc/cmake/modules/AddLibclc.cmake
index 5347b0822477b..0bf6f98452ecd 100644
--- a/libclc/cmake/modules/AddLibclc.cmake
+++ b/libclc/cmake/modules/AddLibclc.cmake
@@ -351,8 +351,9 @@ function(add_libclc_builtin_set)
   add_custom_target( prepare-${obj_suffix} ALL DEPENDS ${obj_suffix} )
   set_target_properties( "prepare-${obj_suffix}" PROPERTIES FOLDER "libclc/Device IR/Prepare" )
 
-  # nvptx-- targets don't include workitem builtins
-  if( NOT ARG_TRIPLE MATCHES ".*ptx.*--$" )
+  # nvptx-- targets don't include workitem builtins, and clspv targets don't
+  # include all OpenCL builtins
+  if( NOT ARG_ARCH MATCHES "^(nvptx|clspv)(64)?$" )
     add_test( NAME external-calls-${obj_suffix}
       COMMAND ./check_external_calls.sh ${CMAKE_CURRENT_BINARY_DIR}/${obj_suffix} ${LLVM_TOOLS_BINARY_DIR}
       WORKING_DIRECTORY ${CMAKE_CURRENT_SOURCE_DIR} )


        


More information about the cfe-commits mailing list